reader

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 23, 2023 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Reader

type Reader struct {
	// contains filtered or unexported fields
}

Reader reads files from the file system

func NewReader

func NewReader(logger *zlog.Logger) *Reader

NewReader creates an instance of a reader

func (*Reader) ReadCSVFile

func (r *Reader) ReadCSVFile(file string) ([][]string, error)

ReadCSVFile get a csv file, use csv reader and retrun string slices

func (*Reader) ReadFile

func (r *Reader) ReadFile(file string) ([]byte, error)

ReadFile get a json or yaml file and return byte slice

Jump to